@@ -209,7 +209,7 @@ const QString indentString(KTextEditor::Document *document)
     return QStringLiteral("\t");
 }
 
-QString getIndendation( const QString &line ) {
+QString getIndentation( const QString &line ) {
     return line.left(line.indexOf(QRegExp("\\S"), 0));
 }
 
