@@ -37,8 +37,8 @@ class PhpDocsConfig
   Q_OBJECT
 
   public:
-    explicit PhpDocsConfig(QWidget *parent = 0, const QVariantList &args = QVariantList());
-    virtual ~PhpDocsConfig();
+    explicit PhpDocsConfig(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
+    ~PhpDocsConfig() override;
 
     void save() override;
 
