@@ -41,6 +41,7 @@ private slots:
     void declareClassWithSemiReservedMethod();
     void declareClassWithBaseTypeMethod();
     void classMemberVar();
+    void classMemberVarTypehint();
     void classMemberVarAfterUse();
     void classMemberVarDocBlockType();
     void declareTypehintFunction();
@@ -87,7 +88,10 @@ private slots:
     void classConst();
     void classConst_data();
     void classConstWithTypeHint();
+    void classConstVisibility();
     void semiReservedClassConst();
+    void illegalClassConst();
+    void illegalClassConst_data();
     void fileConst();
     void fileConst_data();
     void semiReservedFileConst();
@@ -136,6 +140,7 @@ private slots:
     void foreachIterator2();
     void foreachIterator3();
     void foreachIterator4();
+    void foreachArray();
     void returnThis();
     void unsureReturnType();
     void unsureReturnType2();
